<?php
function getArmoryContent($page, $args, $rootNode = "page", $sendAsBrowser = true) {
	global $addon_conf;

	$host = $addon_conf['ArmorySync']['Host'];
	if ($addon_conf['ArmorySync']['UseCurl']) {
		$content = getContentCurl($host, $page, $args, $sendAsBrowser);
	} else {
		$content = getContentFileSocket($host, $page, $args, $sendAsBrowser);
	}

	//if (!($content = strstr($content, "<" . $rootNode))) {
	//	//Throw Error
	//	print "CRITICAL ERROR - no root XML node found: " . $host . $request . " " . $rootNode . "<br>" . $buffer;
	//}

	return $content;
}

function getContentCurl($host, $page, $args, $sendAsBrowser = true) {
	global $addon_conf;

	$url = $host . "/" . $page . "?" . $args;
	$useragent = "User-Agent: Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2";
	$cookie = "cookieLangId=".$addon_conf['ArmorySync']['ArmoryLocale'].";";

	if ($addon_conf['ArmorySync']['DebugLevel'] >= 1) {
		print "GetContentCurl: " . $url . ", " . $sendAsBrowser . ", " . $useragent . ", " . $cookie . "<br>";
	}

	$ch = curl_init($url);
	curl_setopt ($ch, CURLOPT_RETURNTRANSFER, true);
	curl_setopt ($ch, CURLOPT_COOKIE, $cookie);
	if ($sendAsBrowser) {
		curl_setopt ($ch, CURLOPT_USERAGENT, $useragent);
	}
	$content = curl_exec($ch);
	curl_close ($ch);

	if ($addon_conf['ArmorySync']['DebugLevel'] >= 2) {
		print $content . "<br>";
	}

	return $content;
}

function getContentFileSocket($host, $page, $args, $sendAsBrowser = true) {
	global $addon_conf;

	$request = "/" . $page . "?" . $args;
	$useragent = "User-Agent: Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US; rv:1.8.1.2) Gecko/20070219 Firefox/2.0.0.2";
	$cookie = "cookieLangId=".$addon_conf['ArmorySync']['ArmoryLocale'].";";
	$content = '';


	if ($addon_conf['ArmorySync']['DebugLevel'] >= 1) {
		print "GetContentFileSocket: " . $request. ", " . $sendAsBrowser . ", " . $useragent . "<br>";
	}

	if ($fp = fsockopen($host, 80, $errno, $errstr, 30)) {
		stream_set_timeout($fp, 30);
		$buffer = '';

		$headers =
			"GET $request HTTP/1.0\r\n" .
			"Host: $host\r\n".
			(($sendAsBrowser) ? $useragent : "") .
			//"Content-Length: " . strlen($request) . "\r\n" .
			"Connection: close\r\n".
			"Cookie: $cookie\r\n".
			"\r\n";

		if ($addon_conf['ArmorySync']['DebugLevel'] >= 1) {
			print "headers: ". $headers . "<br>";
		}

		fwrite($fp, $headers);
		while (!feof($fp)) {
			$content .= fread($fp, 8192);
		}
		fclose($fp);
	} else {
		//Throw Error
		print "CRITICAL ERROR - socket not connected";
	}

	//If not using CURL we may get the header returned before the HTML table..
	$pos = stripos_b ($content, '<');
	if ($pos != 0){
		//Need to trim header off..
		$content = substr ($content, $pos);
	}
	//Now split off the HTML header..
	//anything up to the first xml need to go
	$pos = stripos_b ($content, '<?xml');

	if ($pos != 0){
		//Need to trim header off..
		$content = substr ($content, $pos);
	}

	if ($addon_conf['ArmorySync']['DebugLevel'] >= 2) {
		print "<!-- Content: ".$content. "--> <br><br>";
	}

	return $content;
}

function stripos_b($haystack, $needle){
    return strpos($haystack, stristr( $haystack, $needle ));
}

function DecodeChunked($body) {
    $crlf = "\r\n";

    // $chunks[0] = chunk length (hex string, ends with $crlf)
    // $chunks[1] = chunk data
    $chunks = explode($crlf, $body, 2);
    $chunk_len = hexdec($chunks[0]);

    while($chunk_len!=0){
    	$decodedPage .= substr($chunks[1],0,$chunk_len);

	$chunks = explode($crlf, $chunks[1], 2);
	$chunk_len = hexdec($chunks[0]);
    }
    return $decodedPage;
}

function convertDate($armoryDate) {
	global $roster_conf, $addon_conf, $wordings;

	$marray = array("January","February","March","April","May","June","July","August","September","October","November","December");
	$armoryDate = str_replace($addon_conf['ArmorySync']['ServerMonth'], $marray, $armoryDate);

	return date("Y-m-d 00:00:00", strtotime($armoryDate));
}

function getRepValue($value) {
	$value = abs($value);

	if ($value >= 42000 && $value < 43000) { $value -= 42000; }
	elseif ($value >= 21000 && $value < 42000) { $value -= 21000; }
	elseif ($value >= 9000 && $value < 21000) { $value -= 9000;  }
	elseif ($value >= 3000 && $value < 9000) { $value -= 3000; }
	elseif ($value >= -3000 && $value < 3000) { $value -= 0;  }
	elseif ($value >= -6000 && $value < -3000) { $value -= 3000; }
	elseif ($value >= -42000 && $value < -6000) { $value -= 6000; }

	return $value;
}

function getRepCap($value) {
	if ($value >= 42000 && $value < 43000) { return 1000; }
	if ($value >= 21000 && $value < 42000) { return 21000; }
	if ($value >= 9000 && $value < 21000) { return 12000; }
	if ($value >= 3000 && $value < 9000) { return 6000; }
	if ($value >= -6000 && $value < 3000) { return 3000; }
	if ($value >= -42000 && $value < -6000) { return 36000; }

	return 0;
}

function getRepStanding($value) {
	global $wordings, $roster_conf;

	if ($value >= 42000 && $value < 43000) { return $wordings[$roster_conf['roster_lang']]['exalted']; }
	if ($value >= 21000 && $value < 42000) { return $wordings[$roster_conf['roster_lang']]['revered']; }
	if ($value >= 9000 && $value < 21000) { return $wordings[$roster_conf['roster_lang']]['honored']; }
	if ($value >= 3000 && $value < 9000) { return $wordings[$roster_conf['roster_lang']]['friendly']; }
	if ($value >= 0 && $value < 3000) { return $wordings[$roster_conf['roster_lang']]['neutral']; }
	if ($value >= -3000 && $value < 0) { return $wordings[$roster_conf['roster_lang']]['unfriendly']; }
	if ($value >= -6000 && $value < -3000) { return $wordings[$roster_conf['roster_lang']]['hostile']; }
	if ($value >= -42000 && $value < -6000) { return $wordings[$roster_conf['roster_lang']]['hated']; }

	return "";
}

function getRepAtWar($value) {
	if ($value >= -3000) { return 0; }
	else { return 1; }
}

function getItemColor($value) {
	switch ($value) {
		case 5: return "ff8000"; //Orange
		case 4: return "a335ee"; //Purple
		case 3: return "0070dd"; //Blue
		case 2: return "1eff00"; //Green
		case 1: return "ffffff"; //White
		default: return "9d9d9d"; //Grey
	}
}

function getItemSlot($value) {
	switch ($value) {
		case 0: return "Head";
		case 1: return "Neck";
		case 2: return "Shoulder";
		case 3: return "Shirt";
		case 4: return "Chest";
		case 5: return "Waist";
		case 6: return "Legs";
		case 7: return "Feet";
		case 8: return "Wrist";
		case 9: return "Hands";
		case 10: return "Finger0";
		case 11: return "Finger1";
		case 12: return "Trinket0";
		case 13: return "Trinket1";
		case 14: return "Back";
		case 15: return "MainHand";
		case 16: return "SecondaryHand";
		case 17: return "Ranged";
		case 18: return "Tabard";
	}
}

function getSkillOrder($value) {
	switch ($value) {
		case "Class Skills": return 1;
		case "Professions": return 2;
		case "Secondary Skills": return 3;
		case "Weapon Skills": return 4;
		case "Armor Proficiencies": return 5;
		case "Languages": return 6;
		default: return 0;
	}
}

function getItemIcon($value) {
	$parts = explode("_", $value);
	$prefix = "";
	$icon = "";

	for($i = 0; $i < sizeof($parts); $i++) {
		if ($i == 0) {
			$part = strtoupper($parts[$i]);
		} else {
			$part = ucfirst($parts[$i]);
		}

		switch ($part) {
			case "Ahnqiraj": $part = "AhnQiraj"; break;
			case "Qirajidol": $part = "QirajIdol"; break;
			case "Guildtabard": $part = "GuildTabard"; break;
		}

		if (substr($part, 0, 11) == "Datacrystal") { $part = "DataCrystal" . substr($part, 11); }

		$icon .= $prefix . $part;
		$prefix = "_";
	}

	return $icon;
}

function displayMessages($message) {
	print "<ul>\n".$message."</ul>\n";
}

function displayErrors($message) {
	print
		'<div id="errorCol" style="display:inline;">
			'.border('sred','start',"<div style=\"cursor:pointer;width:550px;\" onclick=\"swapShow('errorCol','error')\"><img src=\"".$roster_conf['img_url']."plus.gif\" style=\"float:right;\" /><span class=\"red\">Update Errors</span></div>").'
			'.border('sred','end').'
		</div>
		<div id="error" style="display:none">
		'.border('sred','start',"<div style=\"cursor:pointer;width:550px;\" onclick=\"swapShow('errorCol','error')\"><img src=\"".$roster_conf['img_url']."minus.gif\" style=\"float:right;\" /><span class=\"red\">Update Errors</span></div>").
		$message.
		border('sred','end').
		'</div>';
}

function displayGuildMessages($message = null, $updated = null, $added = null, $removed = null, $guildName = null) {
	print
		"<li><strong>Updating Members</strong>\n<ul>\n"
		. $message
		. "</ul></li>\n"
		. "<strong>Updating Guild [<span class=\"orange\">$guildName</span>]</strong>\n<ul>\n"
		. "<li><strong>Member Log</strong>\n<ul>\n"
		. "<li>Updated: " . $updated . "</li>\n"
		. "<li>Added: " . $added . "</li>\n"
		. "<li>Removed: ".$removed . "</li>\n"
		. "</ul>\n<br/>\n";
}

function getTalentBackground($class, $tree) {
	$background = $class . str_replace(" ", "", $tree);

	switch ($tree) {
		case "Elemental":
		case "Feral":
			$background .= "Combat";
			break;
		case "Retribution":
			$background = $class . "Combat";
			break;
		case "Affliction":
			$background = $class . "Curses";
			break;
		case "Demonology":
			$background = $class . "Summoning";
			break;
	}

	return $background;
}

function getDelocalisedClass($class) {
	global $addon_conf, $wordings, $roster_conf;
	$ret = $class;

	if ($addon_conf['ArmorySync']['DebugLevel'] >= 2) {
		print "<!--\n getDelocalisedClass for $class\n";
	}
	foreach ( $wordings[$roster_conf['roster_lang']]['ArmorySynch']['Classes'] as $key => $value ) {
		$value = utf8_encode($value);
		if ( $value == $class ) {
			if ($addon_conf['ArmorySync']['DebugLevel'] >= 2) {
				print "getDelocalisedClass $value equals $class\n";
			}
			$ret = $key;
			break;
		} else {
			if ($addon_conf['ArmorySync']['DebugLevel'] >= 2) {
				print "getDelocalisedClass $value equals not $class\n";
			}
		}
	}
	if ($addon_conf['ArmorySync']['DebugLevel'] >= 2) {
		print "getDelocalisedClass returns $ret for $class\n -->";
	}
	return $ret;
}

function getDelocalisedTalenttree($tree, $class) {
	global $addon_conf, $wordings, $roster_conf;
	$ret = $tree;

	if ($addon_conf['ArmorySync']['DebugLevel'] >= 2) {
		print "<!--\n getDelocalisedTalenttree for $tree of class $class\n";
	}
	foreach ( $wordings[$roster_conf['roster_lang']]['ArmorySynch']['Talenttrees'][$class] as $key => $value ) {
		$value = utf8_encode($value);
		if ( $value == $tree ) {
			if ($addon_conf['ArmorySync']['DebugLevel'] >= 2) {
				print "getDelocalisedTalenttree $value equals $tree\n";
			}
			$ret = $key;
			break;
		} else {
			if ($addon_conf['ArmorySync']['DebugLevel'] >= 2) {
				print "getDelocalisedTalenttree $value equals not $tree\n";
			}
		}
	}
	if ($addon_conf['ArmorySync']['DebugLevel'] >= 2) {
		print "getDelocalisedTalenttree returns $ret for $tree\n -->";
	}
	return $ret;
}

?>
