<?php
function parseGuild($attribs, &$guild) {
	if ($attribs->hasProp("guildName")) {
		$guild["Name"] = $attribs->guildName;
	} elseif ($attribs->hasProp("name")) {
		$guild["Name"] = $attribs->name;
	}
	//$guild["server"] = $attribs->realm;
	//$guild["faction"] = $attribs->faction;
}

function parseMembers($members, &$players) {
	foreach($members->character as $member) {
		$player = array();
		$player["Name"] = $member->name;
		$player["Class"] = $member->class;
		$player["Rank"] = $member->rank;
		$player["Level"] = $member->level;
		$player["Online"] = 0; //Default to 0 so no Last Online is set

		$players[$member->name] = $player;
	}
}

function parsePlayer($attribs, &$player) {
	$player["Name"] = $attribs->character->name;
	$player["Attributes"]["Defense"]["DodgeChance"] = $attribs->characterTab->defenses->dodge->percent;
	$player["Attributes"]["Defense"]["BlockChance"] = $attribs->characterTab->defenses->block->percent;
	$player["Attributes"]["Defense"]["ArmorReduction"] = $attribs->characterTab->defenses->armor->percent;
	$player["Attributes"]["Melee"]["CritChance"] = $attribs->characterTab->melee->critChance->percent;
	$player["Honor"]["Lifetime"]["HK"] = $attribs->characterTab->pvp->lifetimehonorablekills->value;
	$player["Attributes"]["Stats"]["Intellect"] = $attribs->characterTab->baseStats->intellect->base . ":" . ($attribs->characterTab->baseStats->intellect->effective - $attribs->characterTab->baseStats->intellect->base) . ":0";
	$player["Attributes"]["Stats"]["Agility"] = $attribs->characterTab->baseStats->agility->base . ":" . ($attribs->characterTab->baseStats->agility->effective - $attribs->characterTab->baseStats->agility->base) . ":0";
	$player["Attributes"]["Stats"]["Stamina"] = $attribs->characterTab->baseStats->stamina->base . ":" . ($attribs->characterTab->baseStats->stamina->effective - $attribs->characterTab->baseStats->stamina->base) . ":0";
	$player["Attributes"]["Stats"]["Strength"] = $attribs->characterTab->baseStats->strength->base . ":" . ($attribs->characterTab->baseStats->strength->effective - $attribs->characterTab->baseStats->strength->base) . ":0";
	$player["Attributes"]["Stats"]["Spirit"] = $attribs->characterTab->baseStats->spirit->base . ":" . ($attribs->characterTab->baseStats->spirit->effective - $attribs->characterTab->baseStats->spirit->base) . ":0";
	$player["Attributes"]["Defense"]["Armor"] = $attribs->characterTab->defenses->armor->base . ":" . ($attribs->characterTab->defenses->armor->effective - $attribs->characterTab->defenses->armor->base) . ":0";
	//$player["Attributes"]["Defense"]["Defense"] = "0:0:0";
	$player["Attributes"]["Resists"]["Frost"] = $attribs->characterTab->resistances->frost->value . ":0:0";
	$player["Attributes"]["Resists"]["Arcane"] = $attribs->characterTab->resistances->arcane->value . ":0:0";
	$player["Attributes"]["Resists"]["Fire"] = $attribs->characterTab->resistances->fire->value . ":0:0";
	$player["Attributes"]["Resists"]["Shadow"] = $attribs->characterTab->resistances->shadow->value . ":0:0";
	$player["Attributes"]["Resists"]["Nature"] = $attribs->characterTab->resistances->nature->value . ":0:0";
	$player["Level"] = $attribs->character->level;
	$player["Server"] = $attribs->character->realm;
	$player["TalentPoints"] = ($attribs->character->level > 0) ? $attribs->character->level - $attribs->characterTab->talentSpec->treeOne - $attribs->characterTab->talentSpec->treeTwo - $attribs->characterTab->talentSpec->treeThree - 9 : 0;
	//$player["Money"]["Copper"] = 0;
	//$player["Money"]["Silver"] = 0;
	//$player["Money"]["Gold"] = 0;
	//$player["Experience"] = 0;
	$player["Race"] = $attribs->character->race;
	$player["Class"] = $attribs->character->class;
	if ( substr($player["Class"] ,0,1) == 'J' && substr($player["Class"] ,-3) == 'ger' ) {
		$player["Class"] = utf8_encode('Jger');
	}
	$player["Health"] = $attribs->characterTab->characterBars->health->effective;
	$player["Mana"] = $attribs->characterTab->characterBars->secondBar->effective;
	$player["Sex"] = $attribs->character->gender;
 	if ( substr($player["Sex"],0,1) == 'M' && substr($player["Sex"],-6) == 'nnlich' ) {
		$player["Sex"] = utf8_encode('Mnnlich');
	}
 	//$player["Hearth"] = "";
	$player["timestamp"]["init"]["DateUTC"] = convertDate($attribs->character->lastModified);
	//$player["CPversion"] = 0;
	$player["TimePlayed"] = 0; //Needed, otherwise WoWDB will kick out this character
	$player["TimeLevelPlayed"] = 0; //Needed, otherwise WoWDB will kick out this character
	$player["Attributes"]["Melee"]["AttackPower"] = $attribs->characterTab->melee->power->effective . ":0:0";
	$player["Attributes"]["Melee"]["MainHand"]["AttackSkill"] = $attribs->characterTab->melee->mainHandWeaponSkill->value;
	$player["Attributes"]["Melee"]["MainHand"]["DamageRange"] = $attribs->characterTab->melee->mainHandDamage->min . ":" . $attribs->characterTab->melee->mainHandDamage->max;
	//$player["Attributes"]["Melee"]["DamageRangeTooltip"] = "";
	//$player["Attributes"]["Melee"]["AttackPowerTooltip"] = "";
	$player["Attributes"]["Ranged"]["AttackPower"] = $attribs->characterTab->ranged->power->effective . ":0:0";
	$player["Attributes"]["Ranged"]["AttackSkill"] = $attribs->characterTab->ranged->weaponSkill->value;
	$player["Attributes"]["Ranged"]["DamageRange"] = $attribs->characterTab->ranged->damage->min . ":" . $attribs->characterTab->ranged->damage->max;
	//$player["Attributes"]["Ranged"]["DamageRangeTooltip"] = "";
	//$player["Attributes"]["Ranged"]["AttackPowerTooltip"] = "";

	$player["Quests"] = array(); //No info for this from Armory
  $player["Inventory"] = array(); //No info for this from Armory
}

function parseEquipment($equipmentItems, &$equipment, $player) {
	foreach($equipmentItems as $equipmentItem) {
		$item["Item"] = $equipmentItem->id;
		$item["Icon"] = getItemIcon($equipmentItem->icon);

		$xml_parser = new SimpleParser;

		$tries = 0;
		$content = "";
		do {
			$content = getArmoryContent("item-tooltip.xml", "i=" . $equipmentItem->id . "&r=" . urlencode($player["Server"]) . "&n=". $player["Name"]);
			$tries++;

			if (!empty($content)) {
				$armoryItem = $xml_parser->parse($content);
				$item["Color"] = getItemColor($armoryItem->itemTooltips->itemTooltip->overallQualityId->_CDATA);
				$item["Name"] = $armoryItem->itemTooltips->itemTooltip->name->_CDATA;
			}
		} while (empty($content) && $tries <= 10);
		if ($tries > 1) {
			print "Retried " . $tries . "times for: " . "item-tooltip.xml?i=" . $equipmentItem->id . "&r=" . $player["Server"] . "&n=". $player["Name"] . "<br>";
		}

		$tries = 0;
		$content = "";
		do {
			$content = getArmoryContent("item-tooltip.xml", "i=" . $equipmentItem->id . "&r=" . urlencode($player["Server"]) . "&n=". $player["Name"], "table", false);
			$tries++;

			if (!empty($content)) {
				$item["Tooltip"] = trim(str_replace("\n\n", "\n", str_replace("<br />", "\n", strip_tags(nl2br($content)))));
			}
		} while (empty($content) && $tries <= 10);
		if ($tries > 1) {
			print "Retried " . $tries . "times for: " . "item-tooltip.xml?i=" . $equipmentItem->id . "&r=" . $player["Server"] . "&n=". $player["Name"] . "<br>";
		}

		$equipment[getItemSlot($equipmentItem->slot)] = $item;
	}
}

function parseSkills($realm, $charName, &$skills) {

	$content = getArmoryContent("character-skills.xml", "r=" . urlencode($realm) . "&n=" . $charName);

	if (empty($content)) {
		//throw Error
		print "Non-Critical Error: Empty Content for " . $charName . ".  Player has probably not updated in awhile.<br>\n";
		return;
	}

	$xml_parser = new SimpleParser;
	$xml_parser->parse($content);
	$xml = $xml_parser->data->characterInfo;

	if (empty($xml->skillTab)) {
		//throw Error
		print "Non-Critical Error: Incomplete Skill Data for " . $charName . ".  Player has probably not updated in awhile.<br>\n";
		return;
	}

	$skillSets = $xml->skillTab->skillCategory;

	foreach ($skillSets as $order => $skillSet) {
		$type = $skillSet->name;
		$skills[$type] = array();

		if (is_array($skillSet->skill)) {
			foreach($skillSet->skill as $skill) {
				setSkill($skill, $skills[$type]);
			}
		} else {
			setSkill($skillSet->skill, $skills[$type]);
		}

		$skills[$type]["Order"] = getSkillOrder($type);
	}
}

function setSkill($skill, &$output) {
	$output[$skill->name] = $skill->value . ":" . (($skill->max > 0) ? $skill->max : 1);
}

function parseReputation($realm, $charName, &$reputation) {

	$content = getArmoryContent("character-reputation.xml", "r=" . urlencode($realm) . "&n=" . $charName);

	if (empty($content)) {
		//throw Error
		print "Non-Critical Error: Empty Content for " . $charName . ".  Player has probably not updated in awhile.<br>\n";
		return;
	}

	$xml_parser = new SimpleParser;
	$xml_parser->parse($content);
	$xml = $xml_parser->data->characterInfo;

	if (empty($xml->reputationTab)) {
		//throw Error
		print "Non-Critical Error: Incomplete Reputation Data for " . $charName . ".  Player has probably not updated in awhile.<br>\n";
		return;
	}

	$factionReputation = $xml->reputationTab->factionCategory;

	foreach ($factionReputation as $factionRep) {
		$factionType = $factionRep->name;

		if (is_array($factionRep->faction)) {
			foreach($factionRep->faction as $faction) {
				setFaction($faction, $reputation[$factionType]);
			}
		} else {
			setFaction($factionRep->faction, $reputation[$factionType]);
		}
	}
}

function setFaction($faction, &$output) {
	$output[$faction->name] = array();
	$output[$faction->name]["Value"] = getRepValue($faction->reputation) . ":" . getRepCap($faction->reputation);
	$output[$faction->name]["Standing"] = getRepStanding($faction->reputation);
	$output[$faction->name]["AtWar"] = getRepAtWar($faction->reputation);
}

function parseTalents($player, &$rosterTalents) {
	global $talents, $talentTrees, $talentIcons, $roster_conf;

	$xml_parser = new SimpleParser;
	$content = getArmoryContent("character-talents.xml", "r=" . urlencode($player["Server"]) . "&n=" . $player["Name"]);
	$content = $xml_parser->parse($content);
	$armoryTalents = $content->characterInfo->talentTab->talentTree->value;
	$talentArray = preg_split('//', $armoryTalents, -1, PREG_SPLIT_NO_EMPTY);
	//$class = strtolower($player["Class"]);
	$dl_class = getDelocalisedClass($player["Class"]);
	$class = strtolower($dl_class);
	$locale = $roster_conf['roster_lang'];

	for ($i = 0; $i < sizeof($talentArray); $i++) {
		$talentName = $talents[$locale][$class][$i]["name"];
		$talentX = $talents[$locale][$class][$i]["x"];
		$talentY = $talents[$locale][$class][$i]["y"];
		$talentRank = $talentArray[$i];
		$talentMax = sizeof($talents[$locale][$class][$i]["rank"]);
		$talentDesc = $talents[$locale][$class][$i]["rank"][(($talentRank > 0) ? $talentRank -1 : 0)];
		$talentTree = $talents[$locale][$class][$i]["tree"];
		$talentTreeOrder = $talentTrees[$locale][$class][$talentTree]["rank"];
		$talentPic = $talentIcons[$class][$talentTreeOrder][$talentX][$talentY];
		$pointsSpent[$talentTree] += $talentRank;

		$talent = array(
			"Location" => $talentY . ":" . $talentX,
			"Tooltip" => $talentName . "<br>Rank " . $talentRank ."/" . $talentMax . "<br>" . $talentDesc,
			"Icon" => $talentPic,
			"Rank" => $talentRank . ":" . $talentMax
		);

		$rosterTalents[$talentTree][$talentName] = $talent;
		$rosterTalents[$talentTree]["Order"] = $talentTreeOrder;
		//$rosterTalents[$talentTree]["Background"] = getTalentBackground($player["Class"], $talentTree);
		$dl_talentTree = getDelocalisedTalenttree($talentTree, $dl_class);
		$rosterTalents[$talentTree]["Background"] = getTalentBackground($dl_class, $dl_talentTree);
		$rosterTalents[$talentTree]["PointsSpent"] = $pointsSpent[$talentTree];
	}
}
?>
