<?php
require_once ($addonDir."functions.general.php");
require_once ($addonDir."functions.parsing.php");
require_once ($addonDir."talents.php");
require_once ($addonDir."talentIcons.php");
require_once ($addonDir."simpleparser.php");

if (!defined('ROSTER_INSTALLED')) {
	exit('Detected invalid access to this file!');
}

function synchGuild($synchPlayers = true, $realm = null, $guildName = null) {
	global $wowdb, $roster_conf, $addon_conf;
	
	if (empty($realm)) {
		$realm = $roster_conf['server_name'];
	}
	
	if (empty($guildName)) {
		$guildName = $roster_conf['guild_name'];
	}
	
	if (($rosterData = getGuildInfo($realm, $guildName)) && $addon_conf['ArmorySync']['UpdateRoster']) {
		$guild = $rosterData[$realm]['Guild'][$guildName];
		$currentTimestamp = time();
		$currentTime = getDate($currentTimestamp);
		
		// Update the guild
		$guildId = $wowdb->update_guild($realm, $guildName, $currentTime, $guild);
		$guildMembers = $guild['Members'];
	
		// update the list of guild members
		$guildMessages = $wowdb->getMessages();
		foreach(array_keys($guildMembers) as $char_name) {
			$char = $guildMembers[$char_name];
			$wowdb->update_guild_member($guildId, $char_name, $char, $currentTimestamp, array());
			$guildMessages .= $wowdb->getMessages();
			$wowdb->resetMessages();
		}
		
		// Remove the members who were not in this list
		$wowdb->remove_guild_members($guildId, $currentTime);
		$wowdb->remove_guild_members_id($guildId);
		$guildMessages .= $wowdb->getMessages();
		$wowdb->resetMessages();
	
		displayGuildMessages($guildMessages, $wowdb->membersupdated, $wowdb->membersadded, $wowdb->membersremoved, $guildName);
		if ($synchPlayers) {
			synchPlayers(null, array_keys($guildMembers));
		}
	}
}

function synchPlayer($realm = null, $charName, $displayMessages = true) {
	global $wowdb, $roster_conf, $addon_conf;
	
	if (empty($realm)) {
		$realm = $roster_conf['server_name'];
	}
	
	if (empty($charName)) {
		//Throw Error
		print "CRITICAL ERROR: No Player Given.<br>\n";
		return;
	}
	
	$startTime = time();
	if (($rosterData = getPlayerInfo($realm, $charName)) && $addon_conf['ArmorySync']['UpdateRoster']) {
		$guildInfo = $wowdb->get_guild_info($roster_conf['server_name'], $roster_conf['guild_name']);
			
		$wowdb->update_char($guildInfo['guild_id'], $charName, $rosterData);
		
		if ($displayMessages) {
			displayMessages($wowdb->getMessages());
			displayErrors($wowdb->getErrors());
		}
	}
}

function synchMemberByID($realm = null, $memberID, $memberstep, $memberstotal, $displayMessages = true) {
	global $wowdb, $roster_conf, $addon_conf;

	//Print 'Entered [synchMemberByID] with memberID (' . $memberID . ')passed in';
	if (empty($realm)) {
		$realm = $roster_conf['server_name'];
	}

	if (empty($memberID)) {
		//Throw Error
		print "CRITICAL ERROR: No Player Given.<br>\n";
		return;
	}

	$startTime = time();

	//Get player name from member id

	$query =
		"SELECT name " .
		"FROM `".ROSTER_MEMBERSTABLE."` members WHERE member_id=" .  $memberID;

	$result = $wowdb->query($query)
		or die_quietly($wowdb->error(), 'Database Error', basename(__FILE__), __LINE__, $query);


	$membername = '';
	while ($row = $wowdb->fetch_assoc($result)) {
		$membername = $row["name"];
	}

	if ($membername == ''){
		print 'Failed to get member name!';
	}
	else {
		//Ok process this player, then output code to redirect for next run
		Print 'Scanned Player: ' . $membername. '<br>';
		if ($rosterData = getPlayerInfo($realm, $membername)) {
			$guildInfo = $wowdb->get_guild_info($roster_conf['server_name'], $roster_conf['guild_name']);
			$wowdb->update_char($guildInfo['guild_id'], $membername, $rosterData);

			if ($displayMessages) {
				displayMessages($wowdb->getMessages());
				if ($errors = $wowdb->getErrors()) {
					displayErrors($errors);
				}
			}
		}

		
		
		//Get next players id
		$query =
			"SELECT min(members.member_id) ID " .
			"FROM `".ROSTER_MEMBERSTABLE."` members ".
			"LEFT JOIN `".ROSTER_PLAYERSTABLE."` players " .
			"ON members.name = players.name " .
			"WHERE members.member_id > $memberID ".
			"AND members.level >= " . $addon_conf['ArmorySync']['MinLevel'] . " " .
			"AND ( ISNULL(players.name) ";
		if ( $addon_conf['ArmorySync']['IsMySQLLower411'] ) {

			$query .= "OR CONCAT(  '200', MID( players.dateupdatedutc, 8, 1  ) ,  '-', MID( players.dateupdatedutc, 1, 2  ) ,  '-', MID( players.dateupdatedutc, 4, 2  ) ,  ' ', MID( players.dateupdatedutc, 10, 8  )  )  <= DATE_SUB(NOW(), INTERVAL " . $addon_conf['ArmorySync']['SynchCutoffTime'] . " MINUTE) ) ";
		} else {
		
			$query .= "OR STR_TO_DATE(players.dateupdatedutc,'". $addon_conf['ArmorySync']['DateUpdatedFormat'] ."') <= DATE_SUB(UTC_TIMESTAMP(), INTERVAL " . $addon_conf['ArmorySync']['SynchCutoffTime'] . " MINUTE))";
			$wowdb->query("set sql_mode = ''");
		}

		$result = $wowdb->query($query)
			or die_quietly($wowdb->error(), 'Database Error', basename(__FILE__), __LINE__, $query);

		$nextmemberid = -1;
		while ($row = $wowdb->fetch_assoc($result)) {
			$nextmemberid = $row["ID"];
		}

		Print '<br>';
		OutputProgressBar ($memberstep, $memberstotal);
		Print '<br>';

		
		if ( !$nextmemberid or $nextmemberid == -1){
			print 'Finished Processing Members';
		}
		else {
			//Get next member name...
			$query =
				"SELECT members.name " .
				"FROM `".ROSTER_MEMBERSTABLE."` members where member_id = $nextmemberid" ;
	
			if ( !$addon_conf['ArmorySync']['IsMySQLLower411'] ) {
				$wowdb->query("set sql_mode = ''");
			}
	
			$result = $wowdb->query($query)
				or die_quietly($wowdb->error(), 'Database Error', basename(__FILE__), __LINE__, $query);
	
			while ($row = $wowdb->fetch_assoc($result)) {
				$nextmembername = $row["name"];
			}

			//Output javascript to move to process next player...
			Print 'Next Player: ' . $nextmembername . '<br>';
			//$percdone = round ($membersleft / $memberstotal * 100);
			//Print "Progress: $percdone% $membersleft out of $memberstotal";
			//Print "Progress: $membersleft players to go";
			//Print '<pre>' . $module_name . '</pre>';
			$memberstep = $memberstep + 1;
			
			$link = '';
			if ( $addon_conf['ArmorySync']['IsWoWRosterDF'] ) {
				$link = 'index.php?name=WoWRosterDF&file=addon&roster_addon_name=ArmorySynch&syncmemberid='.$nextmemberid.'&step='.$memberstep.'&total='.$memberstotal;
			} else {
				$link = 'addon.php?roster_addon_name=ArmorySynch&syncmemberid='.$nextmemberid.'&step='.$memberstep.'&total='.$memberstotal;
			}
			//Link to next player
			Print '<script LANGUAGE="JavaScript">';
			Print 'function nextMember() {';
			Print '	window.location="' . $link . '";';
			Print '}';
			Print "self.setTimeout('nextMember()', 5000);";
			Print '</script>';
		}
	}
}

function OutputProgressBar($step, $total) {
	$perc = round ($step / $total * 100);
	$pb = "<TABLE class=\"main_roster_menu\" cellspacing=0 cellpadding=0 border=1 width=200 ID=\"Table1\">";
	$pb .= "<TR>";
	$pb .= "<TD class=\"header\" colspan = 2>";
	$pb .= "$perc% complete ($step of $total)";
	$pb .= "	</TD>";
	$pb .= "</TR>";
	$pb .= "<TR>";
	$pb .= "	<TD bgcolor=#660000 height = 10px width=$perc%>" ;
	$pb .= "	</TD>";
	$pb .= "	<TD bgcolor=#FFF7CE>";
	$pb .= "    </TD>";
	$pb .= "</TR>";
	$pb .= "</TABLE>";
	print ($pb);
}

function synchPlayers($realm, $players) {
	global $wowdb, $roster_conf;
	
	print $wowdb->getMessages();
	$wowdb->resetMessages();
	
	if (empty($realm)) {
		$realm = $roster_conf['server_name'];
	}
	
	if (empty($players) || !is_array($players)) {
		//Throw Error
		print "CRITICAL ERROR: No Player Given or Empty Array.<br>\n";
		return;
	}
	
	$startTime = time();
	foreach($players as $player) {
		$playerStartTime = time();
		
		synchPlayer(null, $player, false);
		
		print $player . " synched: " . (time() - $playerStartTime) . " seconds.  Total runtime: " . (time() - $startTime) . " seconds.<br>\n";
		flush();
	}
	
	displayMessages($wowdb->getMessages());
	displayErrors($wowdb->getErrors());
}

function getGuildInfo($realm, $guildName) {
	global $roster_conf;
	
	if (empty($realm)) {
		//Throw Error
		print "CRITICAL ERROR: No Guild Realm Given.<br>\n";
		return;
	}
	
	if (empty($guildName)) {
		//Throw Error
		print "CRITICAL ERROR: No Guild Name Given.<br>\n";
		return;
	}
	
	$content = getArmoryContent("guild-info.xml", "r=" . urlencode($realm) . "&n=" . urlencode($guildName));
	
	if (empty($content)) {
		//throw Error
		print "CRITICAL ERROR: Empty Content for Guild.<br>\n";
		return;
	}
	
	$xml_parser = new SimpleParser;
	$xml_parser->parse($content);
	$xml = $xml_parser->data->guildInfo->guild;
	
	if (empty($xml)) {
		//throw Error
		print "CRITICAL ERROR: Incomplete Data for Guild.<br>\n";
		return;
	}
	
	$guild = array();
	$players = array();
		
	parseGuild($xml, $guild);
	$guild["Locale"] = $roster_conf['roster_lang'];
	$guild["Server"] = $realm;
	parseMembers($xml->members, $players);
	
	/*
	Unnecessary - thanks Pleeg
	if ($numPages > 1) {
		for ($i = 2; $i <= $numPages; $i++) {
			$content = getArmoryContent("guild-info.xml", "r=" . $realm . "&n=" . $guildName . "&p=" . $i);
			
			if (empty($content) || $dataNotFound) {
				//throw Error
			}
			
			$xml_parser = new SimpleParser;
			$xml_parser->parse($content);
			$xml = $xml_parser->data->guildInfo;
			
			parseMembers($xml->guild->members, $players);
		}
	}
	*/
	
	$rosterData[$realm]["Guild"][$guildName] = $guild;
	$rosterData[$realm]["Guild"][$guildName]["Members"] = $players;
	
	if ($addon_conf['ArmorySync']['DebugLevel'] >= 1) {
		print "GuildInfo:<br><pre>";
		print_r($rosterData);
		print "</pre><br>";
	}
	
	return $rosterData;
}

function getPlayerInfo($realm, $charName) {
	global $roster_conf, $addon_conf;
	
	if (empty($charName)) {
		//Throw Error
		print "CRITICAL ERROR: No Name given for Player.<br>\n";
		return;
	}
	
	$content = getArmoryContent("character-sheet.xml", "r=" . urlencode($realm) . "&n=" . $charName);
	
	if (empty($content)) {
		//throw Error
		print "Non-Critical Error: Empty Content for " . $charName . ".  Player has probably not updated in awhile.<br>\n";
		return;
	}
	
	$xml_parser = new SimpleParser;
	$xml_parser->parse($content);
	$xml = $xml_parser->data->characterInfo; 
	
	if (empty($xml->characterTab)) {
		//throw Error
		print "Non-Critical Error: Incomplete Data for " . $charName . ".  Player has probably not updated in awhile.<br>\n";
		return;
	}
	
	$guild = array(); 
	$player = array();
	$skills = array(); 
	$repuation = array();
	$equipment = array();
	$talents = array();
	
	parseGuild($xml->character, $guild);
	parsePlayer($xml, $player);
	$player["Locale"] = $addon_conf['ArmorySync']['Locale'];
	parseSkills($realm, $charName, $skills);
	parseReputation($realm, $charName, $reputation);
	parseEquipment($xml->characterTab->items->item, $equipment, $player);
	parseTalents($player, $talents);
	
	$rosterData = $player;
	$rosterData["Guild"] = $guild;
	$rosterData["Reputation"] = $reputation;
	$rosterData["Equipment"] = $equipment;
	$rosterData["Skills"] = $skills;
	$rosterData["Talents"] = $talents;
	
	if ($addon_conf['ArmorySync']['DebugLevel'] >= 1) {
		print "Player Info:<br><pre>";
		print_r($rosterData);
		print "</pre><br>";
	}
		
	return $rosterData;
}
?>